@@ -3,13 +3,20 @@ package App::RPi::EnvUI::Event;
 use Async::Event::Interval;
 use Data::Dumper;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub new {
-    return bless {}, shift;
+    my ($class, %args) = @_;
+    return bless {%args}, shift;
 }
 sub env_to_db {
-    my ($self, $api) = @_;
+    my ($self) = @_;
+
+    my $db = App::RPi::EnvUI::DB->new(testing => $self->{testing});
+    my $api = App::RPi::EnvUI::API->new(testing => $self->{testing});
+
+    $api->{db} = $db;
+    $self->{db} = $db;
 
     my $event = Async::Event::Interval->new(
         $api->_config_core('event_fetch_timer'),
@@ -22,7 +29,13 @@ sub env_to_db {
     return $event;
 }
 sub env_action {
-    my ($self, $api) = @_;
+    my ($self) = @_;
+
+    my $db = App::RPi::EnvUI::DB->new(testing => $self->{testing});
+    my $api = App::RPi::EnvUI::API->evt(testing => $self->{testing});
+
+    $api->{db} = $db;
+    $self->{db} = $db;
 
     my $event = Async::Event::Interval->new(
         $api->_config_core('event_action_timer'),
